@@ -20,7 +20,8 @@ class BioerProtocol(Station):
             pk_volume_tube = 320,
             vol_pk_offset = 5,
             vol_mm_offset = 10,
-            mm_volume_tube = 1380,
+            mm_volume = 17,
+            mm_volume_tube = 1800,
             headroom_vol_from_tubes_to_pcr = 60,
             headroom_vol_from_tubes_to_dw = 10,
             control_well_positions = ['G12', 'H12'],
@@ -43,7 +44,7 @@ class BioerProtocol(Station):
         self._elution_volume = 12
         self._pk_volume = 10
         self._pk_volume_tube = pk_volume_tube
-        self._mm_volume = 18
+        self._mm_volume = mm_volume
         self._mm_volume_tube = mm_volume_tube
         self._mm_tube_bottom_height = mm_tube_bottom_height
         self._dw_bottom_height = dw_bottom_height
@@ -186,8 +187,8 @@ class BioerProtocol(Station):
             vol_pk = len(samples_to_do) * self._pk_volume
             if num_cycle == 1:
                 self._s300.aspirate(self._vol_pk_offset, self._tube_block.wells()[0].bottom(self._pk_tube_bottom_height))
-            self._pk_tube_source.calculate_aspirate_volume(vol_pk)
-            self._pk_tube_source.aspirate(self._s300, self._pk_tube_bottom_height)
+            self._pk_tube_source.prepare_aspiration(vol_pk, self._pk_tube_bottom_height)
+            self._pk_tube_source.aspirate(self._s300)
             #self.logger.info("Aspirating {} at: {} mm".format(vol_pk, self._pk_tube_bottom_height))
             for s, ss in enumerate(samples_to_do):
                 self._s300.dispense(self._pk_volume, ss.bottom(self._dw_bottom_height))
@@ -232,8 +233,8 @@ class BioerProtocol(Station):
             if num_cycle > 1:
                 self._vol_mm_offset = 0
             vol_mm = (len(samples_to_do) * self._mm_volume) + self._vol_mm_offset
-            self._mm_tube_source.calculate_aspirate_volume(vol_mm)
-            self._mm_tube_source.aspirate(self._s300, self._mm_tube_bottom_height)
+            self._mm_tube_source.prepare_aspiration(vol_mm, min_height=self._mm_tube_bottom_height)
+            self._mm_tube_source.aspirate(self._s300)
             # self.logger.info("Aspirating at: {} mm".format(self._mm_tube_bottom_height))
             for s, ss in enumerate(samples_to_do):
                 self._s300.dispense(self._mm_volume, ss.bottom(self._mm_plate_bottom_height))
@@ -366,12 +367,12 @@ class BioerProtocol(Station):
         else:
             super(BioerProtocol, self).drop(pip)
 
-class BioerPreparationToBioer(BioerProtocol):
-    def __init__(self, ** kwargs):
-        super(BioerPreparationToBioer, self).__init__(
-            mix_beads_phase = False,
-            transfer_proteinase_phase = True,
-            ** kwargs)
+# class BioerPreparationToBioer(BioerProtocol):
+#     def __init__(self, ** kwargs):
+#         super(BioerPreparationToBioer, self).__init__(
+#             mix_beads_phase = False,
+#             transfer_proteinase_phase = True,
+#             ** kwargs)
 
 class BioerPreparationToPcr(BioerProtocol):
     def __init__(self, ** kwargs):
