@@ -1,4 +1,7 @@
-from opentrons.protocol_api import ProtocolContext
+import json
+import os
+
+from opentrons.protocol_api import ProtocolContext, InstrumentContext, PairedInstrumentContext
 from opentrons.protocol_api.labware import Well
 from opentrons.types import Location
 import logging
@@ -151,22 +154,85 @@ class WellWithVolume:
         self._min_height = min_height
         self._headroom_height = headroom_height
 
+    @property
+    def height(self) -> float:
+        if self._well.diameter:
+            remaining_height = self._volume / (math.pi * (self._well.diameter/2)**2)
+        else:
+            remaining_height = self._volume / self._well.length**2
+
+        remaining_height -= self._headroom_height
+        final_height = max(remaining_height, self._min_height)
+        return final_height
+
     def extract_vol_and_get_height(self, aspirate_vol: float) -> float:
         """Return the maximum height to aspirate safely a volume from a well
         :param aspirate_vol: The volume to aspirate
         :returns: the maximum height to aspirate safely the volume in the well"""
         self._volume = self._volume - aspirate_vol if self._volume > aspirate_vol else 0
 
-        if self._well.diameter:
-            remaining_height = self._volume / (math.pi * self._well.diameter**2)
+        return self.height
+
+    def fill(self, vol: float):
+        """Return the maximum height to aspirate safely a volume from a well
+        :param vol: The volume being dispensed in the well"""
+
+        self._volume = self._volume + vol
+        if self._volume < 0:
+            self._volume = 0
+
+
+class MoveWithSpeed:
+    """Class to make easy aspirate and dispense approaching with a defined speed.
+    This should be useful with viscous liquid in order not to break the external meniscus on tip avoiding drops"""
+    def __init__(self, pip: Union[InstrumentContext, PairedInstrumentContext],
+                 from_point: Location,
+                 to_point: Location,
+                 speed,
+                 move_close: bool = True,
+                 go_away: bool = True,
+                 logger: logging.Logger = logging.getLogger("MovieWithSpeed")):
+        """Class initialization
+        :param pip: pipette to move;
+        :param from_point: first point to reach at default speed and last point to leave;
+        :param to_point: target point; from from_point to this point the speed parameter is used;
+        :param speed: speed for the movement between from_point and to_point and back
+        :param move_close: speed is set going towards to_point
+        :param go_away: speed is set going back to from_point."""
+        self._move_close = move_close
+        self._go_away = go_away
+        self._pip = pip
+        self._from_point = from_point
+        self._to_point = to_point
+        self._speed = speed
+        self._logger = logger
+
+        # We want to force_direct only if from and to point are on the same well.
+        if self._to_point.labware.is_well and self._from_point.labware.is_well:
+            self._logger.debug("Both labware are well")
+            self._force_direct = self._to_point.labware.as_well() == self._from_point.labware.as_well()
         else:
-            remaining_height = self._volume / self._well.length**2
-        remaining_height -= self._headroom_height
-        final_height = max(remaining_height, self._min_height)
-        return final_height
+            self._logger.debug("One labware is not well {}, {}".format(self._from_point.labware, self._to_point.labware))
+            self._force_direct = False
+        self._logger.debug("Force direct is: {}".format(self._force_direct))
 
+    def __enter__(self):
+        self._logger.debug("Moving close. Force direct is: {}".format(self._force_direct))
+        if self._move_close:
+            self._pip.move_to(self._from_point)
+            self._pip.move_to(self._to_point, force_direct=self._force_direct, speed=self._speed)
+        else:
+            self._pip.move_to(self._to_point)
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self._logger.debug("Moving close. Force direct is: {}".format(self._force_direct))
+        self._pip.move_to(self._to_point)       # for safety, since we've a force_direct set on next move_to
+        self._pip.move_to(self._from_point, force_direct=self._force_direct, speed=self._speed if self._go_away else None)
 
 
+def get_labware_json_from_filename(filename: str = ""):
+    with open(os.path.join(os.path.dirname(__file__), 'labware', filename)) as f:
+        return json.load(f)
 
 
 # Copyright (c) 2020 Covmatic.
